pub struct Await(pub Ident);👎Deprecated: The
rust_grammar module has been spun out into the separate crates loess-rust and loess-rust-opaque.Expand description
await
Tuple Fields
0: Ident👎Deprecated: The
rust_grammar module has been spun out into the separate crates loess-rust and loess-rust-opaque.Trait Implementations
Sourceimpl IntoTokens for Await
impl IntoTokens for Await
Sourcefn into_tokens(self, root: &TokenStream, tokens: &mut impl Extend<TokenTree>)
fn into_tokens(self, root: &TokenStream, tokens: &mut impl Extend<TokenTree>)
Sourcefn collect_tokens<T: Default + Extend<TokenTree>>(self, root: &TokenStream) -> Twhere
Self: Sized,
fn collect_tokens<T: Default + Extend<TokenTree>>(self, root: &TokenStream) -> Twhere
Self: Sized,
Convenience methods to emit
self’s tokens into a new T.Auto Trait Implementations
impl Freeze for Await
impl RefUnwindSafe for Await
impl !Send for Await
impl !Sync for Await
impl Unpin for Await
impl UnwindSafe for Await