pub struct For(pub Ident);👎Deprecated: The
rust_grammar module has been spun out into the separate crates loess-rust and loess-rust-opaque.Expand description
for
Tuple Fields
0: Ident👎Deprecated: The
rust_grammar module has been spun out into the separate crates loess-rust and loess-rust-opaque.Trait Implementations
Sourceimpl IntoTokens for For
impl IntoTokens for For
Sourcefn into_tokens(self, root: &TokenStream, tokens: &mut impl Extend<TokenTree>)
fn into_tokens(self, root: &TokenStream, tokens: &mut impl Extend<TokenTree>)
Sourcefn collect_tokens<T: Default + Extend<TokenTree>>(self, root: &TokenStream) -> Twhere
Self: Sized,
fn collect_tokens<T: Default + Extend<TokenTree>>(self, root: &TokenStream) -> Twhere
Self: Sized,
Convenience methods to emit
self’s tokens into a new T.Auto Trait Implementations
impl Freeze for For
impl RefUnwindSafe for For
impl !Send for For
impl !Sync for For
impl Unpin for For
impl UnwindSafe for For