Struct Input

pub struct Input {
    pub tokens: VecDeque<TokenTree>,
    pub end: Span,
}
Input tokens with end-Span.
For use with PeekFrom and PopFrom.

Also has some convenience methods.

Fields

tokens: VecDeque<TokenTree>end: Span

This currently is usually a “one-token-past-the-end”-Span.
Top-level input should default to Span::call_site().

If Span::end is stabilised, then that will be a better option and should be used instead where applicable.

Implementations

Source

impl Input

pub fn peek<'a, const N: usize>( &'a self, f: impl FnOnce([&TokenTree; N], Iter<'a, TokenTree>) -> bool, ) -> bool

Convenience method to match an array of &TokenTrees.

This is mostly for PeekFrom implementations.
Grammar consumers should call Token::peek_from instead.

Iff self is long enough, f is called with references to the frontmost tokens and a vec_deque::Iter over the remaining tokens after them.

Returns

false if self is too short, otherwise the return value of f.

pub fn pop_or_replace<'a, T, const N: usize>( &'a mut self, f: impl FnOnce([TokenTree; N], &mut Self) -> Result<T, [TokenTree; N]>, ) -> Result<T, impl 'a + IntoIterator<Item = Span>>

Convenience method to match from an array of TokenTrees.

This is mostly for PopFrom implementations.
Grammar consumers should call Token::pop_from instead.

Iff self is long enough, f is called with the frontmost tokens and an &mut Input pointing to self.

Returns

If self is too short or f returns Err, respective Spans to create an Error with.

Iff self is too short, self.end is included.

pub fn is_empty(&self) -> bool

pub fn len(&self) -> usize

pub fn front(&self) -> Option<&TokenTree>

pub fn front_span(&self) -> Span

Returns the frontmost token’s Span or else self.end.

pub fn push_front(&mut self, t: TokenTree)

pub fn prepend( &mut self, tokens: impl IntoIterator<Item = TokenTree, IntoIter: DoubleEndedIterator>, )